@@ -76,6 +76,7 @@ init_scene_Accel(AWallpaperPlugin *desktop_plugin)
     GPtrArray *child;
     gint now = time(NULL);
     gchar *str;
+    gchar *bgfile = NULL;
     gint sizes1[4] = {57, 76, 43, 50},
          n, j;
     
@@ -84,7 +85,8 @@ init_scene_Accel(AWallpaperPlugin *desktop_plugin)
     scene->actors = NULL;
     desktop_plugin->priv->scene = scene;
     
-    actor = init_object(desktop_plugin, "background", "bg.png", 
+    bgfile = g_strdup_printf("/home/user/.backgrounds/background-%i.png", desktop_plugin->priv->view);
+    actor = init_object(desktop_plugin, "original", bgfile, 
                       0, 0, 0, 800, 480, 
                       TRUE, TRUE, 100, 255, 
                       NULL, NULL, NULL);
@@ -268,6 +270,9 @@ init_scene_Video(AWallpaperPlugin *desktop_plugin)
     }
     file_plus_uri = g_strdup_printf("file://%s",desktop_plugin->priv->theme_string_parametr1);
     g_object_set (G_OBJECT (bin), "uri", file_plus_uri, NULL );
+    /* Set Mute */
+    if (!desktop_plugin->priv->theme_bool_parametr1)
+        g_object_set (G_OBJECT (bin), "mute", TRUE, NULL );
     g_object_set (G_OBJECT (videosink), "force-aspect-ratio", TRUE, NULL  );
 
     if (GST_IS_X_OVERLAY (videosink))
