@@ -34,10 +34,10 @@ void lw_about(void){
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
     vbox = gtk_vbox_new (FALSE, 5);
-    label_about = gtk_label_new (_("Live Wallpaper Version 0.8 \n Copyright(c) 2010\n \
+    label_about = gtk_label_new (_("Live Wallpaper Version 0.8.1 \n Copyright(c) 2010\n \
 Tanya Makova\n Vlad Vasiliev\n \
 Copyright(c) 2010 for design themes Berlin, Modern and Accel Vasya Bobrikov\n \
-Copyright(c) 2010 for design theme Matrix Andrew Zhilin\n \
+Copyright(c) 2010 for design theme Matrix and icons Andrew Zhilin\n \
 Translators:\n \
 Finnish - Marko Vertainen\n \
 Spain  - Alejandro López\n \
@@ -66,6 +66,11 @@ create_category_selector (Animation_WallpaperPrivate *priv){
             g_hash_table_insert(result_table, g_hash_table_lookup(store->data, "category"), (gint *)1);     
         store = g_slist_next(store);
     }
+    
+    /* Add Xscreensaver for install message */
+    if (!g_hash_table_lookup(result_table,"Xscreensaver"))
+            g_hash_table_insert(result_table, "Xscreensaver", (gint *)1);
+   
 
     category_list = g_hash_table_get_keys (result_table);
     selector = hildon_touch_selector_new_text();
@@ -81,8 +86,7 @@ create_category_selector (Animation_WallpaperPrivate *priv){
 
 /*******************************************************************************/
 void
-theme_button_clicked(GtkButton *button, Animation_WallpaperPrivate *priv){
-
+theme_button_clicked(GtkWidget *button, GdkEventButton *event, Animation_WallpaperPrivate *priv){
     lw_theme_settings(GTK_WIDGET(button), priv);
 }
 /********************************************************************************/
@@ -94,6 +98,7 @@ set_button_image(GtkWidget * button, Animation_WallpaperPrivate *priv, gboolean
     gchar *icon_on = NULL;
     gchar *icon_off = NULL;
     GSList *store = priv->extheme_list;
+
     while (store){
         if (!strcmp(priv->theme, g_hash_table_lookup(store->data, "name"))){
             icon_on = g_strdup(g_hash_table_lookup(store->data, "icon_on"));
@@ -108,16 +113,27 @@ set_button_image(GtkWidget * button, Animation_WallpaperPrivate *priv, gboolean
         else 
             str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
                             priv->theme, "icon.png");
+            if (access(str, F_OK) != 0){
+                g_free(str);
+                str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
+                            "Video", "icon.png");
+            }
+
     }else {
         if (icon_off)
             str = g_strdup_printf("%s", icon_off);
-        else
+        else 
             str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
                             priv->theme, "icond.png");
+            if (access(str, F_OK) != 0){
+                g_free(str);
+                str = g_strdup_printf( "%s/%s/%s", THEME_PATH, 
+                            "Video", "icond.png");
+            }
     }
     pixbuf = gdk_pixbuf_new_from_file_at_size (str, 
-                                                 100, 
-                                                 60, 
+                                                 124, 
+                                                 79, 
                                                  NULL);
     if (str)
         g_free(str);
@@ -130,13 +146,22 @@ set_button_image(GtkWidget * button, Animation_WallpaperPrivate *priv, gboolean
         g_object_unref(G_OBJECT(pixbuf));
     }
 
-   hildon_button_set_image (HILDON_BUTTON (button), image);
+    //hildon_button_set_image (HILDON_BUTTON (button), image);
+    GList *list = gtk_container_get_children(GTK_CONTAINER (button));
+    if (list){
+        gtk_container_remove(GTK_CONTAINER (button), list->data);
+    }
+    gtk_container_add(GTK_CONTAINER (button), image);
+    gtk_widget_show(image);
+    gtk_widget_show(button);
+
 }
 /********************************************************************************/
 GtkWidget *
 create_image_button (gint view, DBusConnection *conn_sess){
     GtkWidget *button;
-    
+    GtkWidget *event_box;
+
     Animation_WallpaperPrivate *priv = g_new0(Animation_WallpaperPrivate, 1);
     /* Add external themes to priv */
     priv->extheme_list = get_list_exthemes();
@@ -145,6 +170,14 @@ create_image_button (gint view, DBusConnection *conn_sess){
     priv->theme_string_parametr1 = NULL;
     priv->dbus_conn_session = conn_sess;
     read_config(priv);
+
+    event_box = gtk_event_box_new();
+    g_object_set_data(G_OBJECT(event_box), "view", GINT_TO_POINTER(view));
+    g_object_set_data(G_OBJECT(event_box), "priv", priv);
+    set_button_image(event_box, priv, check_applet_state(view));
+    g_signal_connect(G_OBJECT (event_box), "button_press_event", G_CALLBACK(theme_button_clicked), priv);
+    return event_box;
+#if 0
     button = hildon_button_new(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT,
                                     HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     g_object_set_data(G_OBJECT(button), "view", GINT_TO_POINTER(view));
@@ -153,7 +186,7 @@ create_image_button (gint view, DBusConnection *conn_sess){
     g_signal_connect(button, "clicked", G_CALLBACK(theme_button_clicked), priv);
     hildon_button_set_image_position (HILDON_BUTTON (button), GTK_POS_RIGHT);
     return button;
-
+#endif
 }
 /********************************************************************************/
 void
@@ -161,15 +194,19 @@ changed_value_theme_cb (HildonPickerButton *picker, Animation_WallpaperPrivate *
 {
     const gchar *choice = hildon_button_get_value(HILDON_BUTTON (picker));
     GtkWidget *vbox = NULL;
+    GtkWidget *area_vbox = NULL;
         
+    area_vbox = g_object_get_data(G_OBJECT(priv->window), "area_vbox");
+    if (!area_vbox)
+        return;
     vbox = g_object_get_data(G_OBJECT(priv->window), "custom_vbox");
     if (vbox){
         gtk_widget_destroy(vbox);
     }
-    vbox = gtk_vbox_new (FALSE, 5);
+    vbox = gtk_vbox_new (TRUE, 5);
     g_object_set_data(G_OBJECT(priv->window), "custom_vbox", vbox);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(priv->window)->vbox),
-                                   vbox, TRUE, TRUE, 5);
+    gtk_box_pack_start(GTK_BOX(area_vbox),
+                                   vbox, FALSE, FALSE, 5);
     if (choice) {
         if (!strcmp(choice, _("Berlin"))){
             rich_animation_additional_parametr(vbox,priv);
@@ -195,6 +232,7 @@ void
 changed_value_category_cb (HildonPickerButton *picker, Animation_WallpaperPrivate *priv)
 {
     GtkWidget *theme_button = NULL;
+    const gchar *choice = hildon_button_get_value(HILDON_BUTTON (picker));
 
     theme_button = g_object_get_data(G_OBJECT(priv->window), "theme_button");
     if (!theme_button) 
@@ -203,12 +241,22 @@ changed_value_category_cb (HildonPickerButton *picker, Animation_WallpaperPrivat
     hildon_touch_selector_remove_column(selector, 0); 
     hildon_touch_selector_append_text_column(selector, (GtkTreeModel*)gtk_list_store_new (1, G_TYPE_STRING), TRUE);
     fill_theme_button(priv, theme_button, (gchar *)hildon_button_get_value(HILDON_BUTTON (picker)));
+    /* check xscreensaver category */
+    if (choice){
+        if (!strcmp(choice,"Xscreensaver"))
+            if (access("/usr/bin/xscreensaver", F_OK) != 0){
+                hildon_banner_show_information(GTK_WIDGET(picker), NULL, 
+                _("You haven't got the installed package Xscreensaver. Please install it via using Application Manager"));
+            }
+
+    }
 }
 /********************************************************************************/
 void
 fill_theme_button (Animation_WallpaperPrivate *priv, GtkWidget *button, gchar *category){
 
     gchar *theme = priv->theme;
+    gboolean flag = False;
     gint num=0;
         hildon_button_set_value(HILDON_BUTTON (button), NULL);
     if (!category){
@@ -264,8 +312,21 @@ fill_theme_button (Animation_WallpaperPrivate *priv, GtkWidget *button, gchar *c
         }
         store = g_slist_next(store);
     }
-       
-    hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (button),
+    /* Added Shreman's Aquarium for message */
+    if (!strcmp(category, "Unknown")){
+        store = priv->extheme_list;
+        while (store){  
+            if (!strcmp("Sherman's Aquarium" , g_hash_table_lookup(store->data, "name"))){
+                flag = TRUE;
+                break;
+            }
+            store = g_slist_next(store);
+        }
+        if (!flag)
+            hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "Sherman's Aquarium");
+    }
+
+        hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (button),
                                                        HILDON_TOUCH_SELECTOR (selector));
 
     changed_value_theme_cb(HILDON_PICKER_BUTTON (button), priv);
@@ -275,7 +336,7 @@ GtkWidget *
 create_themes_button (Animation_WallpaperPrivate *priv, gchar *category){
 
     GtkWidget *button;
-    button = hildon_picker_button_new (HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+    button = hildon_picker_button_new (HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     hildon_button_set_title (HILDON_BUTTON (button), _("Theme"));
 
    
@@ -293,7 +354,7 @@ create_categories_button (Animation_WallpaperPrivate *priv){
 
     result_table = g_hash_table_new(g_str_hash, g_str_equal);
     selector = create_category_selector(priv);
-    button = hildon_picker_button_new (HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+    button = hildon_picker_button_new (HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     hildon_button_set_title (HILDON_BUTTON (button), _("Category"));
     hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (button),
                                                        HILDON_TOUCH_SELECTOR (selector));
@@ -319,15 +380,17 @@ create_categories_button (Animation_WallpaperPrivate *priv){
             hildon_button_set_value(HILDON_BUTTON(button), "LiveWallpaper");
         }
         GSList *store = priv->extheme_list;
+        num = 1;
         while (store){
-            if (!g_hash_table_lookup(result_table, g_hash_table_lookup(store->data, "category"))){
+            if (g_hash_table_lookup(result_table, g_hash_table_lookup(store->data, "category")) == NULL){
                 g_hash_table_insert(result_table, g_hash_table_lookup(store->data, "category"), (gint *)num);     
                 num++;
             }
             if (!strcmp(theme, g_hash_table_lookup(store->data, "name"))){
                 if (g_hash_table_lookup(store->data, "category"))
-                    hildon_button_set_value(HILDON_BUTTON(button), _(g_hash_table_lookup(store->data, "category")));
-                    hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, (gint)g_hash_table_lookup(result_table, g_hash_table_lookup(store->data, "category"))); 
+                    hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 
+                    (gint)g_hash_table_lookup(result_table, g_hash_table_lookup(store->data, "category"))); 
+                    hildon_button_set_value(HILDON_BUTTON(button), g_hash_table_lookup(store->data, "category"));
                 break;
             }
 
@@ -339,7 +402,7 @@ create_categories_button (Animation_WallpaperPrivate *priv){
 
 /*******************************************************************************/
 GtkWidget *
-create_rich_animation_button (gboolean active, gchar *name)
+create_bool_button (gboolean active, gchar *name)
 {
     GtkWidget *button;
     button = hildon_check_button_new (HILDON_SIZE_AUTO);
@@ -352,7 +415,7 @@ GtkWidget *
 create_enable_button (gboolean active)
 {
     GtkWidget *button;
-    button = hildon_check_button_new (HILDON_SIZE_AUTO);
+    button = hildon_check_button_new (HILDON_SIZE_FINGER_HEIGHT);
     gtk_button_set_label (GTK_BUTTON (button), _("Enable"));
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(button), active);
     return button;
@@ -381,19 +444,19 @@ lw_main_settings(Animation_WallpaperPrivate *priv, gpointer data){
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
     /* Create Theme button */
-    hbox = gtk_hbox_new(FALSE, 5);
+    hbox = gtk_hbox_new(FALSE, 0);
     theme_button1 = create_image_button(1, priv->dbus_conn_session);
     gtk_box_pack_start(GTK_BOX(hbox),
-                                   theme_button1, TRUE, TRUE, 5);
+                                   theme_button1, TRUE, TRUE, 0);
     theme_button2 = create_image_button(2, priv->dbus_conn_session);
     gtk_box_pack_start(GTK_BOX(hbox),
-                                   theme_button2, TRUE, TRUE, 5);
+                                   theme_button2, TRUE, TRUE, 0);
     theme_button3 = create_image_button(3, priv->dbus_conn_session);
     gtk_box_pack_start(GTK_BOX(hbox),
-                                   theme_button3, TRUE, TRUE, 5);
+                                   theme_button3, TRUE, TRUE, 0);
     theme_button4 = create_image_button(4, priv->dbus_conn_session);
     gtk_box_pack_start(GTK_BOX(hbox),
-                                   theme_button4, TRUE, TRUE, 5);
+                                   theme_button4, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
                                    hbox, TRUE, TRUE, 5);
 
@@ -465,7 +528,7 @@ rich_animation_additional_parametr(GtkWidget *vbox, Animation_WallpaperPrivate *
     GtkWidget *rich_animation_button;
 
     /* Create rich animation button */  
-    rich_animation_button = create_rich_animation_button(priv->rich_animation, _("Rich Animation"));
+    rich_animation_button = create_bool_button(priv->rich_animation, _("Rich Animation"));
     gtk_box_pack_start(GTK_BOX(vbox),
                                    rich_animation_button, TRUE, TRUE, 5);
     g_object_set_data(G_OBJECT(priv->window), "rich_animation_button", rich_animation_button);
@@ -476,6 +539,7 @@ void
 additional_parametr_for_theme_video(GtkWidget *vbox, Animation_WallpaperPrivate *priv){
 
     GtkWidget *file_button;
+    GtkWidget *sound_button;
     GtkWidget *rich_animation_button;
 
     if (priv->theme_string_parametr1)
@@ -489,13 +553,20 @@ additional_parametr_for_theme_video(GtkWidget *vbox, Animation_WallpaperPrivate
 
     gtk_box_pack_start(GTK_BOX(vbox),
                                    file_button, TRUE, TRUE, 5);
-    g_object_set_data(G_OBJECT(priv->window), "filename_button", file_button);    /* Create rich animation button */  
-    rich_animation_button = create_rich_animation_button(priv->rich_animation, _("Loop"));
+    g_object_set_data(G_OBJECT(priv->window), "filename_button", file_button);    
+    /* Create rich animation button */  
+    rich_animation_button = create_bool_button(priv->rich_animation, _("Loop"));
     gtk_box_pack_start(GTK_BOX(vbox),
                                    rich_animation_button, TRUE, TRUE, 5);
     g_object_set_data(G_OBJECT(priv->window), "rich_animation_button", rich_animation_button);
+    /* Create sound button */  
+    sound_button = create_bool_button(priv->theme_bool_parametr1, _("Sound"));
+    gtk_box_pack_start(GTK_BOX(vbox),
+                                   sound_button, TRUE, TRUE, 5);
+    g_object_set_data(G_OBJECT(priv->window), "sound_button", sound_button);
 
     gtk_widget_show (file_button);
+    gtk_widget_show (sound_button);
     gtk_widget_show (rich_animation_button);
 
 }
@@ -504,11 +575,14 @@ void
 lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
     gint result;
     GtkWidget *window = NULL;
+    GtkWidget *scrolled_window = NULL;
     GtkWidget *save_button;
     GtkWidget *theme_button;
     GtkWidget *category_button;
     GtkWidget *enable_button;
     GtkWidget *vbox;
+    GtkWidget *temp_button;
+    GtkWidget *area_vbox;
     GtkWidget *button1 = NULL;
     GtkWidget *rich_animation_button = NULL;
     gint view = priv->view;
@@ -520,16 +594,26 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 
+    /* Create panarea */
+    area_vbox = gtk_vbox_new(FALSE, 2);
+    g_object_set_data(G_OBJECT(window), "area_vbox", area_vbox);
+    scrolled_window = hildon_pannable_area_new ();
+    hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA (scrolled_window), GTK_WIDGET (area_vbox));
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
+                                   scrolled_window, FALSE, FALSE, 0);
+
+    gtk_widget_set_size_request(scrolled_window, -1, 370);
+
     /* Create Enable button */
     enable_button = create_enable_button(check_applet_state(view)); 
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
-                                   enable_button, TRUE, TRUE, 5);
+    gtk_box_pack_start(GTK_BOX(area_vbox),
+                                   enable_button, FALSE, FALSE, 5);
     /* Create Category button */
     category_button = create_categories_button(priv);
     g_object_set_data(G_OBJECT(window), "category_button", category_button);
     g_signal_connect (G_OBJECT (category_button), "value-changed",  G_CALLBACK (changed_value_category_cb), priv);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
-                                   category_button, TRUE, TRUE, 5);
+    gtk_box_pack_start(GTK_BOX(area_vbox),
+                                   category_button, FALSE, FALSE, 5);
     /* Create Custom vbox */
     vbox = gtk_vbox_new (FALSE, 5);
     g_object_set_data(G_OBJECT(window), "custom_vbox", vbox);
@@ -538,18 +622,20 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
     theme_button = create_themes_button(priv, (gchar *)hildon_button_get_value(HILDON_BUTTON (category_button)));
     g_object_set_data(G_OBJECT(window), "theme_button", theme_button);
     g_signal_connect (G_OBJECT (theme_button), "value-changed",  G_CALLBACK (changed_value_theme_cb), priv);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
-                                   theme_button, TRUE, TRUE, 5);
+    gtk_box_pack_start(GTK_BOX(area_vbox),
+                                   theme_button, FALSE, FALSE, 5);
     fill_theme_button(priv, theme_button, (gchar *)hildon_button_get_value(HILDON_BUTTON (category_button)));
 
     /* Pack custom vbox. It must be last widget */
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
-                                   vbox, TRUE, TRUE, 5);
+    gtk_box_pack_start(GTK_BOX(area_vbox),
+                                   vbox, FALSE, FALSE, 5);
 
     gtk_widget_show (enable_button);
     gtk_widget_show (category_button);
     gtk_widget_show (theme_button);
     gtk_widget_show (vbox);
+    gtk_widget_show (area_vbox);
+    gtk_widget_show (scrolled_window);
     gtk_widget_show (window);
 
     save_button = gtk_dialog_add_button(GTK_DIALOG(window), _("Save"), GTK_RESPONSE_YES);
@@ -570,6 +656,15 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
                         break;
                     }
                 }
+                /* Check Xsnow program */
+                if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), "Sherman's Aquarium")){
+                    if (access("/usr/bin/shermans", F_OK) != 0){
+                        hildon_banner_show_information(GTK_WIDGET(button), NULL, 
+                        _("You haven't got the installed package 'Sherman's Aquarium'. Please install it via using Application Manager"));
+                        /* if not scuccess exit from wthout saving */ 
+                        break;
+                    }
+                }
 
                 if (priv->theme)
                     g_free(priv->theme);
@@ -589,6 +684,14 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
                             g_free(priv->theme_string_parametr1);
                         priv->theme_string_parametr1 = g_strdup((gchar*)hildon_button_get_value (HILDON_BUTTON(button1)));
                     }
+                    temp_button = g_object_get_data(G_OBJECT(priv->window), "sound_button");
+                    if (temp_button){
+                        /* Check rich animation */
+                        if (hildon_check_button_get_active (HILDON_CHECK_BUTTON(temp_button)))
+                            priv->theme_bool_parametr1 = TRUE;
+                        else
+                            priv->theme_bool_parametr1 = FALSE;
+                    }
                 }
                 /* Check external themes */
                 GSList *store = priv->extheme_list;
